AdvancedPublisher class

A zenoh advanced publisher with cache, publisher detection, and sample miss detection capabilities.

Wraps ze_owned_advanced_publisher_t. Call close when done to undeclare the publisher and release native resources.

Properties

hashCode int
The hash code for this object.
no setterinherited
keyExpr String
The key expression this advanced publisher is declared on.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Undeclares the advanced publisher and releases native resources.
deleteResource() → void
Sends a DELETE through this advanced publisher.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
put(String value, {Encoding? encoding, ZBytes? attachment}) → void
Publishes a string value through this advanced publisher.
putBytes(ZBytes payload, {Encoding? encoding, ZBytes? attachment}) → void
Publishes ZBytes payload through this advanced publisher.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

declare(Pointer<Void> loanedSession, Pointer<Void> loanedKe, String keyExpr, {bool enableCache = false, int cacheMaxSamples = 0, bool publisherDetection = false, bool sampleMissDetection = false, HeartbeatMode heartbeatMode = HeartbeatMode.none, int heartbeatPeriodMs = 0}) AdvancedPublisher
Creates an advanced publisher on the given session and key expression.