AdvancedSubscriberOptions class
Options for configuring an advanced subscriber.
Constructors
Properties
- detectLatePublishers → bool
-
Whether to detect late publishers and recover their history.
final
- enableMissListener → bool
-
Whether to enable the miss event listener.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- history → bool
-
Whether to recover historical data on subscription.
final
- lastSampleMissDetection → bool
-
Whether to enable last sample miss detection for recovery.
final
- periodicQueriesPeriodMs → int
-
Period in milliseconds for periodic recovery queries (0 = disabled).
final
- recovery → bool
-
Whether to enable sample recovery.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subscriberDetection → bool
-
Whether to enable subscriber detection.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited