zenohSerialized constant

Encoding const zenohSerialized

Zenoh serialized data. This encoding supposes that the payload was created with serialization functions. The schema field may contain the details of serialziation format.

MIME zenoh/serialized.

Implementation

static const zenohSerialized = Encoding('zenoh/serialized');