Hello class
A hello message received during network scouting.
Contains the identity, type, and locators of a discovered zenoh entity.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
locators
→ List<
String> -
The network locators of the discovered entity.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- whatami → WhatAmI
-
The type of the discovered entity (router, peer, or client).
final
- zid → ZenohId
-
The zenoh ID of the discovered entity.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited