acceptsReplies property
Which key expressions this query accepts replies on (default
matchingQuery).
Implementation
final ReplyKeyExpr acceptsReplies;
Which key expressions this query accepts replies on (default
matchingQuery).
final ReplyKeyExpr acceptsReplies;