Reply class

A reply received from a get operation, representing either a successful sample or an error.

Constructors

Reply.error(ReplyError error, {EntityGlobalId? replierId})
Creates an error reply containing a ReplyError.
Reply.ok(Sample sample, {EntityGlobalId? replierId})
Creates an ok reply containing a Sample.

Properties

error ReplyError
Returns the error if this is an error reply.
no setter
hashCode int
The hash code for this object.
no setterinherited
isOk bool
Returns true if this reply contains a successful sample.
no setter
ok Sample
Returns the sample if this is an ok reply.
no setter
replierId EntityGlobalId?
The entity that answered this reply, or null if unavailable (e.g. the unstable API is compiled out). Present for both ok and error replies.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited