isOk property
bool
get
isOk
Returns true if this reply contains a successful sample.
Implementation
bool get isOk => _sample != null;
Returns true if this reply contains a successful sample.
bool get isOk => _sample != null;