replierId property
The entity that answered this reply, or null if unavailable (e.g. the unstable API is compiled out). Present for both ok and error replies.
Implementation
final EntityGlobalId? replierId;
The entity that answered this reply, or null if unavailable (e.g. the unstable API is compiled out). Present for both ok and error replies.
final EntityGlobalId? replierId;