serializeInt32 method

void serializeInt32(
  1. int value
)

Serializes an int32 value.

Throws an ArgumentError naming the domain if value falls outside -2147483648..2147483647, before any native call is made. See the class doc for why the integer widths reject.

Implementation

void serializeInt32(int value) {
  _checkState();
  _requireInRange(value, -2147483648, 2147483647, 'int32');
  final rc = bindings.zd_serializer_serialize_int32(_loanMut().cast(), value);
  if (rc != 0) throw ZenohException('Failed to serialize int32', rc);
}