Zenoh class

Top-level zenoh utilities.

Provides static methods for global zenoh initialization that must be called before opening sessions.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

resolvedLibraryPath String?
The filesystem path libzenoh_dart.so was actually loaded from, or null.
no setter

Static Methods

initLog(String fallback) → void
Initializes the zenoh logger from the RUST_LOG environment variable, falling back to fallback if RUST_LOG is not set.
initLogWithSink({required LogSeverity minSeverity}) Stream<LogRecord>
Routes zenoh's own log records into this application, at minSeverity and above.
scout({Config? config, int timeoutMs = 1000, int what = 3}) Future<List<Hello>>
Scouts for zenoh entities on the network.