zenoh library
Dart bindings for the Zenoh pub/sub/query protocol via FFI.
Classes
- AdvancedPublisher
- A zenoh advanced publisher with cache, publisher detection, and sample miss detection capabilities.
- AdvancedPublisherOptions
- Options for configuring an advanced publisher.
- AdvancedSubscriber
- An advanced subscriber with history recovery and miss detection.
- AdvancedSubscriberOptions
- Options for configuring an advanced subscriber.
- Config
- A Zenoh configuration.
- Encoding
- Represents the encoding of a zenoh payload.
- Hello
- A hello message received during network scouting.
- KeyExpr
- A Zenoh key expression.
- LivelinessToken
- A liveliness token that advertises the session's presence on a key expression for as long as it remains undeclared.
- MissEvent
- Information about missed samples from a source.
- Publisher
- A zenoh publisher for efficiently publishing multiple messages on a single key expression.
- PullSubscriber
- A zenoh pull subscriber that receives samples via a ring buffer.
- Querier
- A zenoh querier for efficiently sending multiple queries on a single key expression with pre-configured options.
- Query
- A received query on a queryable key expression.
- Queryable
- A zenoh queryable that receives queries on a key expression.
- Reply
- A reply received from a get operation, representing either a successful sample or an error.
- ReplyError
- An error payload returned by a queryable instead of a successful reply.
- Sample
- A sample received from a subscriber.
- Session
- A Zenoh session.
- ShmMutBuffer
- A mutable shared memory buffer allocated from an ShmProvider.
- ShmProvider
- A shared memory provider for zero-copy data transfer.
- Subscriber
- A zenoh subscriber that receives samples on a key expression.
- ZBytes
- A Zenoh byte payload.
- ZBytesWriter
- A zenoh bytes writer for assembling raw byte payloads.
- ZDeserializer
- A zenoh deserializer for reading structured payloads.
- Zenoh
- Top-level zenoh utilities.
- ZenohId
- A 16-byte zenoh entity identifier.
- ZSerializer
- A zenoh serializer for building structured payloads.
Enums
- CongestionControl
- Controls the behavior when the outgoing buffer is full.
- ConsolidationMode
- The consolidation mode for replies to a get query.
- HeartbeatMode
- Heartbeat mode for advanced publisher sample miss detection.
- Priority
- The priority of a zenoh message.
- QueryTarget
- The target of a get query.
- SampleKind
- The kind of a sample (put or delete).
- WhatAmI
- The type of a zenoh entity (router, peer, or client).
Exceptions / Errors
- ZenohException
- Exception thrown when a zenoh operation fails.