AdvancedPublisher class
A zenoh advanced publisher with cache, publisher detection, and sample miss detection capabilities.
Wraps ze_owned_advanced_publisher_t. Call close when done to
undeclare the publisher and release native resources.
Properties
Methods
-
close(
) → void - Undeclares the advanced publisher and releases native resources.
-
deleteResource(
) → void - Sends a DELETE through this advanced publisher.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
put(
String value, {Encoding? encoding, ZBytes? attachment}) → void -
Publishes a string
valuethrough this advanced publisher. -
putBytes(
ZBytes payload, {Encoding? encoding, ZBytes? attachment}) → void -
Publishes ZBytes
payloadthrough this advanced publisher. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
declare(
Pointer< Void> loanedSession, Pointer<Void> loanedKe, String keyExpr, {bool enableCache = false, int cacheMaxSamples = 0, bool publisherDetection = false, bool sampleMissDetection = false, HeartbeatMode heartbeatMode = HeartbeatMode.none, int heartbeatPeriodMs = 0}) → AdvancedPublisher - Creates an advanced publisher on the given session and key expression.