AdvancedPublisherOptions class
Options for configuring an advanced publisher.
All fields are optional. When cacheMaxSamples is non-null, caching is enabled with the given maximum sample count (0 means unlimited).
Constructors
- AdvancedPublisherOptions({int? cacheMaxSamples, bool publisherDetection = false, bool sampleMissDetection = false, HeartbeatMode heartbeatMode = HeartbeatMode.none, int heartbeatPeriodMs = 0})
-
Creates advanced publisher options.
const
Properties
- cacheMaxSamples → int?
-
Maximum number of samples to cache. If non-null, caching is enabled.
A value of 0 means unlimited cache.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- heartbeatMode → HeartbeatMode
-
The heartbeat mode for sample miss detection.
final
- heartbeatPeriodMs → int
-
The heartbeat period in milliseconds (used with periodic/sporadic modes).
final
- publisherDetection → bool
-
Whether to enable publisher detection.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sampleMissDetection → bool
-
Whether to enable sample miss detection.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited