AdvancedSubscriber class
An advanced subscriber with history recovery and miss detection.
Wraps ze_owned_advanced_subscriber_t. Samples are delivered
asynchronously via a Stream. Call close when done to undeclare
the subscriber and release native resources.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
missEvents
→ Stream<
MissEvent> ? -
A stream of MissEvents when samples are missed, or null if the
miss listener was not enabled.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
stream
→ Stream<
Sample> -
A stream of Samples received by this advanced subscriber.
no setter
Methods
-
close(
) → void - Undeclares the advanced subscriber and releases native resources.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
declare(
Pointer< Void> loanedSession, Pointer<Void> loanedKe, {AdvancedSubscriberOptions options = const AdvancedSubscriberOptions()}) → AdvancedSubscriber - Creates an advanced subscriber on the given session and key expression.