Encoding class

Represents the encoding of a zenoh payload.

Uses MIME type strings to describe the encoding format. Provides predefined constants for common types and supports custom MIME types via the constructor.

Constructors

Encoding(String mimeType)
Creates an Encoding with the given mimeType.
const

Properties

hashCode int
The hash code for this object.
no setteroverride
mimeType String
The MIME type string for this encoding.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override