Encoding class
Represents the encoding of a zenoh payload.
Uses MIME type strings to describe the encoding format. Provides predefined constants for common types and supports custom MIME types via the constructor.
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- applicationJson → const Encoding
- applicationOctetStream → const Encoding
- applicationProtobuf → const Encoding
- imageJpeg → const Encoding
- imagePng → const Encoding
- textCsv → const Encoding
- textHtml → const Encoding
- textPlain → const Encoding
- zenohBytes → const Encoding
- zenohString → const Encoding