KeyExpr class
A Zenoh key expression.
Wraps z_view_keyexpr_t. The view borrows a native C string that is
allocated by the constructor and freed by dispose.
Must be disposed when no longer needed to release native memory.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
nativePtr
→ Pointer<
Void> -
Internal: returns the native pointer for use by Session.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
Returns the key expression as a Dart string.
no setter
Methods
-
dispose(
) → void - Releases native resources held by this key expression.
-
equals(
KeyExpr other) → bool -
Returns true if this key expression is equal to
otherin zenoh semantics. -
includes(
KeyExpr other) → bool -
Returns true if this key expression includes
other. -
intersects(
KeyExpr other) → bool -
Returns true if this key expression intersects with
other. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited