intersects method

bool intersects(
  1. KeyExpr other
)

Returns true if this key expression intersects with other.

Two key expressions intersect if there exists at least one key that belongs to both sets.

Implementation

bool intersects(KeyExpr other) {
  _ensureNotDisposed();
  other._ensureNotDisposed();
  return bindings.zd_keyexpr_intersects(_kePtr.cast(), other._kePtr.cast());
}