Priority enum

The priority of a zenoh message.

Values are ordered from highest priority (realTime) to lowest (background). The zenoh-c integer values are index + 1 (1–7).

Inheritance
Available extensions

Values

realTime → const Priority
interactiveHigh → const Priority
interactiveLow → const Priority
dataHigh → const Priority
data → const Priority
dataLow → const Priority
background → const Priority

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<Priority>
A constant List of the values in this enum, in order of their declaration.