Publisher class

A zenoh publisher for efficiently publishing multiple messages on a single key expression.

Wraps z_owned_publisher_t. Call close when done to undeclare the publisher and release native resources.

Properties

hashCode int
The hash code for this object.
no setterinherited
keyExpr String
The key expression this publisher is declared on.
no setter
matchingStatus Stream<bool>?
A stream of matching status changes, or null if the matching listener was not enabled when the publisher was declared.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Undeclares the publisher and releases native resources.
deleteResource() → void
Sends a DELETE through this publisher.
hasMatchingSubscribers() bool
Returns whether any subscribers currently match this publisher's key expression.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
put(String value, {Encoding? encoding, ZBytes? attachment}) → void
Publishes a string value through this publisher.
putBytes(ZBytes payload, {Encoding? encoding, ZBytes? attachment}) → void
Publishes ZBytes payload through this publisher.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

declare(Pointer<Void> loanedSession, Pointer<Void> loanedKe, {Encoding? encoding, CongestionControl congestionControl = CongestionControl.block, Priority priority = Priority.data, bool isExpress = false, bool enableMatchingListener = false}) Publisher
Creates a publisher on the given session and key expression.