Queryable class
A zenoh queryable that receives queries on a key expression.
Wraps z_owned_queryable_t. Queries are delivered asynchronously
via a Stream. Call close when done to undeclare the queryable
and release native resources.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- keyExpr → String
-
The key expression this queryable is declared on.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
stream
→ Stream<
Query> -
A stream of Querys received by this queryable.
no setter
Methods
-
close(
) → void - Undeclares the queryable and releases native resources.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited