RecvData<T> class final

The channel delivered a value.

Canon's Z_OK: a value was taken out of the channel's buffer, and value is it.

Inheritance

Constructors

RecvData(T value)
Wraps the value the channel delivered.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value → T
The value the channel delivered.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited