ReplyError class

An error payload returned by a queryable instead of a successful reply.

Constructors

ReplyError({required Uint8List payloadBytes, required String payload, String? encoding})
Creates a ReplyError with the given fields.

Properties

encoding String?
The encoding of the error payload, or null if unspecified.
final
hashCode int
The hash code for this object.
no setterinherited
payload String
The error payload decoded as a UTF-8 string for display.
final
payloadBytes Uint8List
The raw error payload bytes (exact, byte-faithful).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited