AllocError class final
The request was well formed; the provider could not satisfy it.
Canon's ZC_BUF_LAYOUT_ALLOC_STATUS_ALLOC_ERROR — "Allocation error" —
carrying canon's own z_alloc_error_t as kind.
- Inheritance
-
- Object
- AllocResult
- AllocError
Constructors
- AllocError(AllocErrorKind kind)
-
Wraps the allocation-failure
kindcanon reported.const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- kind → AllocErrorKind
-
Why the provider could not satisfy the request.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited